@@ -171,6 +171,8 @@ permission_type_to_string (EphyPermissionType type)
       return "advertisement-permission";
     case EPHY_PERMISSION_TYPE_AUTOPLAY_POLICY:
       return "autoplay-permission";
+    case EPHY_PERMISSION_TYPE_ACCESS_DISPLAY:
+      return "display-device-permission";
     default:
       g_assert_not_reached ();
   }
@@ -516,6 +518,9 @@ ephy_permissions_manager_export_to_js_context (EphyPermissionsManager *manager,
   js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_TYPE_ACCESS_WEBCAM);
   jsc_value_object_set_property (js_enum, "ACCESS_WEBCAM", js_enum_value);
   g_object_unref (js_enum_value);
+  js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_TYPE_ACCESS_DISPLAY);
+  jsc_value_object_set_property (js_enum, "ACCESS_DISPLAY", js_enum_value);
+  g_object_unref (js_enum_value);
   js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_TYPE_SHOW_ADS);
   jsc_value_object_set_property (js_enum, "SHOW_ADS", js_enum_value);
   g_object_unref (js_enum_value);
