@@ -22,6 +22,7 @@
 #include "config.h"
 #include "context-menu-commands.h"
 
+#include "ephy-bookmark-properties.h"
 #include "ephy-downloads-manager.h"
 #include "ephy-embed-container.h"
 #include "ephy-embed-utils.h"
@@ -31,6 +32,7 @@
 #include "ephy-settings.h"
 #include "ephy-shell.h"
 #include "ephy-web-view.h"
+#include "window-commands.h"
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -85,6 +87,9 @@ view_in_destination (EphyWindow      *window,
   webkit_web_view_restore_session_state (WEBKIT_WEB_VIEW (new_view), session_state);
   webkit_web_view_session_state_unref (session_state);
   ephy_web_view_load_url (new_view, value);
+
+  if (g_settings_get_boolean (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_SWITCH_TO_NEW_TAB))
+    gtk_widget_grab_focus (GTK_WIDGET (new_view));
 }
 
 void
@@ -484,6 +489,9 @@ context_cmd_search_selection (GSimpleAction *action,
   new_embed = ephy_shell_new_tab (ephy_shell_get_default (),
                                   EPHY_WINDOW (user_data), embed, EPHY_NEW_TAB_APPEND_AFTER | EPHY_NEW_TAB_JUMP);
   ephy_web_view_load_url (ephy_embed_get_web_view (new_embed), search_url);
+
+  gtk_widget_grab_focus (GTK_WIDGET (ephy_embed_get_web_view (new_embed)));
+
   g_free (search_url);
 }
 
@@ -546,3 +554,28 @@ context_cmd_open_selection_in_incognito_window (GSimpleAction *action,
   open_term = g_variant_get_string (parameter, NULL);
   ephy_open_incognito_window (open_term);
 }
+
+void
+context_cmd_add_link_to_bookmarks (GSimpleAction *action,
+                                   GVariant      *parameter,
+                                   gpointer       user_data)
+{
+  WebKitHitTestResult *hit_test_result;
+  guint context;
+  const char *address;
+
+  hit_test_result = ephy_window_get_context_event (EPHY_WINDOW (user_data));
+  g_assert (hit_test_result != NULL);
+
+  context = webkit_hit_test_result_get_context (hit_test_result);
+
+  if (context & WEBKIT_HIT_TEST_RESULT_CONTEXT_LINK) {
+    EphyWindow *window = EPHY_WINDOW (user_data);
+    GtkWidget *dialog;
+
+    address = webkit_hit_test_result_get_link_uri (hit_test_result);
+
+    dialog = ephy_bookmark_properties_new_for_link (window, address);
+    adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (window));
+  }
+}
