@@ -261,7 +261,7 @@ set_is_all_selected (EphyHistoryDialog *self,
 
   if (is_all_selected)
     gtk_button_set_label (GTK_BUTTON (self->select_all_button),
-                          _("De_select All"));
+                          _("Select _None"));
   else
     gtk_button_set_label (GTK_BUTTON (self->select_all_button),
                           _("Select _All"));
@@ -454,7 +454,6 @@ row_copy_url_button_clicked (GtkWidget *button,
     AdwToast *toast = adw_toast_new (_("Link copied"));
 
     gdk_clipboard_set_text (gtk_widget_get_clipboard (GTK_WIDGET (button)), url->url);
-    adw_toast_set_priority (toast, ADW_TOAST_PRIORITY_HIGH);
     adw_toast_overlay_add_toast (ADW_TOAST_OVERLAY (self->toast_overlay), toast);
   }
 }
